@@ -3,7 +3,7 @@ package App::ThisDist;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-10-11'; # DATE
 our $DIST = 'App-ThisDist'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use strict;
 use warnings;
@@ -17,28 +17,38 @@ our @EXPORT_OK = qw(this_dist);
 sub this_dist {
     require File::Slurper;
 
-    my ($dir) = @_;
+    my ($dir, $extract_version) = @_;
 
-    if (!$dir) {
+    if (defined $dir) {
+        log_debug "chdir to $dir ...";
+    }
+
+    local $CWD = $dir if defined $dir;
+
+    unless (defined $dir) {
         require Cwd;
         $dir = Cwd::getcwd();
     }
+
     (my $dir_basename = $dir) =~ s!.+[/\\]!!;
 
-    local $CWD = $dir;
+    my ($distname, $distver);
 
-    my $dist;
   GUESS: {
       FROM_DISTMETA_2: {
             for my $file ("MYMETA.json", "META.json") {
                 next unless -f $file;
-                log_debug "Found distribution metadata $file in current directory";
+                log_debug "Found distribution metadata $file";
                 require JSON::PP;
                 my $content = File::Slurper::read_text($file);
                 my $meta = JSON::PP::decode_json($content);
                 if ($meta && ref $meta eq 'HASH' && defined $meta->{name}) {
-                    $dist = $meta->{name};
-                    log_debug "Got dist=$dist from distribution metadata $file";
+                    $distname = $meta->{name};
+                    log_debug "Got distname=$distname from distribution metadata $file";
+                    if (defined $meta->{version}) {
+                        $distver = $meta->{version};
+                        log_debug "Got distver=$distver from distribution metadata $file";
+                    }
                     last GUESS;
                 } else {
                     last;
@@ -49,12 +59,16 @@ sub this_dist {
       FROM_DISTMETA_1_1: {
             for my $file ("MYMETA.yml", "META.yml") {
                 next unless -f $file;
-                log_debug "Found distribution metadata $file in current directory";
+                log_debug "Found distribution metadata $file";
                 require YAML::XS;
                 my $meta = YAML::XS::LoadFile($file);
                 if ($meta && ref $meta eq 'HASH' && defined $meta->{name}) {
-                    $dist = $meta->{name};
-                    log_debug "Got dist=$dist from distribution metadata $file";
+                    $distname = $meta->{name};
+                    log_debug "Got distname=$distname from distribution metadata $file";
+                    if (defined $meta->{version}) {
+                        $distver = $meta->{version};
+                        log_debug "Got distver=$distver from distribution metadata $file";
+                    }
                     last GUESS;
                 } else {
                     last;
@@ -64,18 +78,22 @@ sub this_dist {
 
       FROM_DIST_INI: {
             last unless -f "dist.ini";
-            log_debug "Found dist.ini in current directory";
+            log_debug "Found dist.ini";
             my $content = File::Slurper::read_text("dist.ini");
             while ($content =~ /^\s*name\s*=\s*(.+)/mg) {
-                $dist = $1;
-                log_debug "Got dist=$dist from dist.ini";
+                $distname = $1;
+                log_debug "Got distname=$distname from dist.ini";
+                if ($content =~ /^version\s*=\s*(.+)/m) {
+                    $distver = $1;
+                    log_debug "Got distver=$distver from dist.ini";
+                }
                 last GUESS;
             }
         }
 
       FROM_MAKEFILE_PL: {
             last unless -f "Makefile.PL";
-            log_debug "Found Makefile.PL in current directory";
+            log_debug "Found Makefile.PL";
             my $content = File::Slurper::read_text("Makefile.PL");
             unless ($content =~ /use ExtUtils::MakeMaker/) {
                 log_debug "Makefile.PL doesn't seem to use ExtUtils::MakeMaker, skipped";
@@ -85,14 +103,18 @@ sub this_dist {
                 log_debug "Couldn't extract value of DISTNAME from Makefile.PL, skipped";
                 last;
             }
-            $dist = $1;
-            log_debug "Got dist=$dist from Makefile.PL";
+            $distname = $1;
+            log_debug "Got distname=$distname from Makefile.PL";
+            if ($content =~ /["']VERSION["']\s*=>\s*["'](.+?)["']/) {
+                $distver = $1;
+                log_debug "Got distver=$distver from Makefile.PL";
+            }
             last GUESS;
         }
 
       FROM_MAKEFILE: {
             last unless -f "Makefile";
-            log_debug "Found Makefile in current directory";
+            log_debug "Found Makefile";
             my $content = File::Slurper::read_text("Makefile");
             unless ($content =~ /by MakeMaker/) {
                 log_debug "Makefile doesn't seem to be generated from MakeMaker.PL, skipped";
@@ -102,14 +124,18 @@ sub this_dist {
                 log_debug "Couldn't extract value of DISTNAME from Makefile, skipped";
                 last;
             }
-            $dist = $1;
-            log_debug "Got dist=$dist from Makefile.PL";
+            $distname = $1;
+            log_debug "Got distname=$distname from Makefile";
+            if ($content =~ /^VERSION\s*=\s*(.+)/m) {
+                $distver = $1;
+                log_debug "Got distver=$distver from Makefile";
+            }
             last GUESS;
         }
 
       FROM_BUILD_PL: {
             last unless -f "Build.PL";
-            log_debug "Found Build.PL in current directory";
+            log_debug "Found Build.PL";
             my $content = File::Slurper::read_text("Build.PL");
             unless ($content =~ /use Module::Build/) {
                 log_debug "Build.PL doesn't seem to use Module::Build, skipped";
@@ -119,12 +145,13 @@ sub this_dist {
                 log_debug "Couldn't extract value of module_name from Build.PL, skipped";
                 last;
             }
-            $dist = $1; $dist =~ s/::/-/g;
-            log_debug "Got dist=$dist from Build.PL";
+            $distname = $1; $distname =~ s/::/-/g;
+            log_debug "Got distname=$distname from Build.PL";
+            # XXX extract version?
             last GUESS;
         }
 
-        # Build script does not contain dist name
+        # note: Build script does not contain dist name
 
       FROM_GIT_CONFIG: {
             last unless -f ".git/config";
@@ -135,8 +162,9 @@ sub this_dist {
                 log_debug "Found URL '$url' in git config";
                 require CPAN::Dist::FromURL;
                 my $res = CPAN::Dist::FromURL::extract_cpan_dist_from_url($url);
-                if (defined $dist) {
-                    log_debug "Guessed dist=$dist from .git/config URL '$url'";
+                if (defined $distname) {
+                    log_debug "Guessed distname=$distname from .git/config URL '$url'";
+                    # XXX extract version?
                     last GUESS;
                 }
             }
@@ -147,15 +175,16 @@ sub this_dist {
             require CPAN::Dist::FromRepoName;
             my $res = CPAN::Dist::FromRepoName::extract_cpan_dist_from_repo_name($dir_basename);
             if (defined $res) {
-                $dist = $res;
-                log_debug "Guessed dist=$dist from repo name '$dir_basename'";
+                $distname = $res;
+                log_debug "Guessed distname=$distname from repo name '$dir_basename'";
+                # XXX extract version?
                 last GUESS;
             }
         }
 
-        log_debug "Can't guess this distribution, giving up";
+        log_debug "Can't guess distribution, giving up";
     }
-    $dist;
+    $extract_version ? "$distname ".(defined $distver ? $distver : "?") : $distname;
 }
 
 1;
@@ -173,7 +202,7 @@ App::ThisDist - Print Perl {distribution,module,author,...} associated with curr
 
 =head1 VERSION
 
-This document describes version 0.006 of App::ThisDist (from Perl distribution App-ThisDist), released on 2020-10-11.
+This document describes version 0.007 of App::ThisDist (from Perl distribution App-ThisDist), released on 2020-10-11.
 
 =head1 DESCRIPTION
 
@@ -191,6 +220,14 @@ See included scripts:
 
 =head2 this_dist
 
+Usage:
+
+ my $dist = this_dist([ $dir ] [ , $extract_version? ]); => e.g. "App-Foo" or "App-Foo 1.23"
+
+If C<$dir> is not specified, will default to current directory. If
+C<$extract_version> is set to true, will also try to extract distribution
+version and will return "?" when unable to do so.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-ThisDist>.
